@@ -27,6 +27,7 @@ class EnvironementConfig:
     def __init__(self, base_env_vars=None):
         base_env_vars = dict(base_env_vars or {}, **os.environ)
         self.NESTOR_NAME = base_env_vars.get("NESTOR_NAME") or base_env_vars.get("CI_COMMIT_REF_SLUG")
+        self.NESTOR_NAME_PREFIX = base_env_vars.get("NESTOR_NAME_PREFIX")
         self.ALWAYS_DELETE = base_env_vars.get("ALWAYS_DELETE")
         self.CI_COMMIT_REF_NAME = base_env_vars.get("CI_COMMIT_REF_NAME")
         self.CI_PROJECT_DIR = base_env_vars.get("CI_PROJECT_DIR")
@@ -38,7 +39,7 @@ class EnvironementConfig:
         self.S3_DUMP_BUCKET = base_env_vars.get("S3_DUMP_BUCKET")
         self.VERBOSE = bool(base_env_vars.get("VERBOSE"))
         self.DATE = base_env_vars.get("DATE")
-        self.S3_BUCKET = "ndp-preview-" + base_env_vars.get("S3_BUCKET")
+        self.S3_BUCKET = base_env_vars.get("S3_BUCKET")
         self.PROD_INSTANCE_NAME = base_env_vars.get("PROD_INSTANCE_NAME") or base_env_vars.get("CI_PROJECT_NAME")
         self.DB_NAME = base_env_vars.get("DB_NAME")
         self.ODOO_DEPENDS = base_env_vars.get("ODOO_DEPENDS")
@@ -69,6 +70,9 @@ class EnvironementConfig:
         self.S3_DUMP_BUCKET = self.S3_DUMP_BUCKET or "ndp-production-backups"
         self.DATE = self.DATE or date.today().isoformat()
 
+        if self.NESTOR_NAME_PREFIX:
+            self.NESTOR_NAME = f"{self.NESTOR_NAME_PREFIX}-{self.NESTOR_NAME}"
+
     def __repr__(self):
         res = "NESTOR_NAME = " + str(self.NESTOR_NAME)
         res += "\nCI_PROJECT_DIR = " + str(self.CI_PROJECT_DIR)
@@ -122,6 +126,9 @@ class InteractiveConfig(EnvironementConfig):
         log(f"Repertoire du projet ou laisser vide pour utiliser '{CURRENT_PATH}'")
         self.CI_PROJECT_DIR = input("=> ") or CURRENT_PATH
 
+        log(f"Prefix à utliser pour le nom sinon '{self.NESTOR_NAME}'")
+        self.NESTOR_NAME_PREFIX = input("=> ") or ""
+
         log(f"Nom de la base de backup ? (Vide pour le nom de la prod '{self.PROD_INSTANCE_NAME}')")
         self.DB_NAME = input("=> ")
 
